@@ -22,11 +22,11 @@ class ButtonsEntry(EntryBlock):
                 'buttons': [
                     {
                         'type': 'button',
-                        'value': self.mocker.button(btn_one)
+                        'value': self.button(btn_one)
                     },
                     {
                         'type': 'button',
-                        'value': self.mocker.button(btn_two)
+                        'value': self.button(btn_two)
                     },
                 ],
                 'align': align
