@@ -46,6 +46,9 @@ HomePage = get_model('cms', 'HomePage')
 ContentPage = get_model('cms', 'ContentPage')
 BlogPage = get_model('cms', 'BlogPage')
 BlogIndexPage = get_model('cms', 'BlogIndexPage')
+PortfolioPage = get_model('cms', 'PortfolioPage')
+PortfolioIndexPage = get_model('cms', 'PortfolioIndexPage')
+
 WebspaceSettings = get_model('cms', 'WebspaceSettings')
 MyDocument = get_model('cms', 'MyDocument')
 Form = get_model('cms', 'Form')
@@ -195,7 +198,7 @@ class Command(BaseCommand):
 
         article_list = []
         i = 1
-        while i < 10:
+        while i < 3:
             file_desktop = mocker.SVG_BG_DESKTOP_SPACE if i % 2 else mocker.IMG_BG_DESKTOP_SPACE
             file_mobile = mocker.SVG_BG_MOBILE_SPACE if i % 2 else mocker.IMG_BG_MOBILE_SPACE
             cover = mocker.SVG_BLOG_COVER_LIGHT if i % 2 else mocker.IMG_BLOG_COVER_LIGHT
@@ -252,6 +255,71 @@ class Command(BaseCommand):
             ])
             article.save()
 
+        # -------------------------------- Portfolio Pages --------------------------------
+
+        portfolios_page = PortfolioIndexPage(
+            title="Portfolio",
+            slug='portfolio',
+            bg_desktop=json.dumps([{
+                'type': 'svg',
+                'value': mocker.file(mocker.SVG_BG_DESKTOP_SPACE).id
+            }]),
+            bg_mobile=json.dumps([{
+                'type': 'svg',
+                'value': mocker.file(mocker.SVG_BG_MOBILE_SPACE).id
+            }]),
+            first_text=mocker.text_first_content
+        )
+        home_page.add_child(instance=portfolios_page)
+        portfolios_menu_id = mocker.menu(portfolios_page)
+        mocker.add_menu(portfolios_page, home_page_menu_id)
+        mocker.add_menu(home_page, portfolios_menu_id)
+
+        portfolio_list = []
+        i = 1
+        while i < 3:
+            cover = mocker.SVG_BLOG_COVER_LIGHT if i % 2 else mocker.IMG_BLOG_COVER_LIGHT
+            portfolio_page = PortfolioPage(
+                title="Portfolio %s" % (str(i)),
+                slug='portfolio-%s' % (str(i)),
+                body=json.dumps([
+                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
+                    svg_entry.mock(container='content', theme=constants.THEME_LIGHT),
+                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
+                    svg_entry.mock(force_file=mocker.SVG_CONTENT_HEIGHT_LIGHT, container='content',
+                                   theme=constants.THEME_LIGHT),
+                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
+                    image_entry.mock(container='content', theme=constants.THEME_LIGHT),
+                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
+                    image_entry.mock(force_file=mocker.IMG_CONTENT_HEIGHT_LIGHT, container='content',
+                                     theme=constants.THEME_LIGHT),
+                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
+                    embed_entry.mock(container='content', theme=constants.THEME_LIGHT),
+                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
+                ]),
+                cover=json.dumps([{
+                    'type': ('svg' if i % 2 else 'image'),
+                    'value': mocker.file(cover).id
+                }]),
+                intro=mocker.h,
+            )
+            portfolio_page.tags.add('Uks' if i % 2 else 'Kaks')
+            portfolios_page.add_child(instance=portfolio_page)
+            mocker.menu(portfolio_page, portfolios_menu_id)
+            mocker.add_menu(portfolio_page, home_page_menu_id)
+            portfolio_list.append(portfolio_page)
+            i += 1
+
+        related = {
+            'type': 'portfolio',
+            'value': portfolio_list[0].id
+        }
+        for portfolio in portfolio_list:
+            portfolio.related_portfolio = json.dumps([
+                related, related, related
+            ])
+            portfolio.save()
+
         # -------------------------------- Example --------------------------------
 
         # -------------------------------- Cards --------------------------------
@@ -624,6 +692,11 @@ class Command(BaseCommand):
         <hr>
         """
 
+        ws_settings.related_portfolios_text = """
+        <h2>Portfolios related</h2>
+        <hr>
+        """
+
         ws_settings.newsletter = Mocker.get_form('newsletter', nb_fields=1, head_text=False)
 
         ws_settings.facebook = mocker.URL_TEST
@@ -676,7 +749,9 @@ class Command(BaseCommand):
             "user",
             "accordion",
             "fr",
-            "en"
+            "en",
+            "star_enable",
+            "star_disable",
         ]
         for key in keys:
             ico, created = IconSnippet.objects.get_or_create(
