@@ -77,10 +77,8 @@ if not is_model_registered('cms', 'FormSubmission'):
 
     __all__.append('FormSubmission')
 
-
 from .snippets.person import APerson
 
-
 if not is_model_registered('cms', 'Person'):
     @register_snippet
     class Person(APerson):
@@ -89,7 +87,6 @@ if not is_model_registered('cms', 'Person'):
 
     __all__.append('Person')
 
-
 #  Pages
 
 
@@ -152,7 +149,6 @@ if not is_model_registered('cms', 'DocumentPage'):
 
     __all__.append('DocumentPage')
 
-
 from .pages._generic import AMultiLanguagePage
 
 if not is_model_registered('cms', 'MultiLanguagePage'):
@@ -162,6 +158,28 @@ if not is_model_registered('cms', 'MultiLanguagePage'):
 
     __all__.append('MultiLanguagePage')
 
+from .pages.portfolio import APortfolioIndexPage, APortfolioPage, APortfolioPageTag
+
+if not is_model_registered('cms', 'PortfolioPageTag'):
+    class PortfolioPageTag(APortfolioPageTag):
+        pass
+
+
+    __all__.append('PortfolioPageTag')
+
+if not is_model_registered('cms', 'PortfolioIndexPage'):
+    class PortfolioIndexPage(APortfolioIndexPage):
+        pass
+
+
+    __all__.append('PortfolioIndexPage')
+
+if not is_model_registered('cms', 'PortfolioPage'):
+    class PortfolioPage(APortfolioPage):
+        pass
+
+
+    __all__.append('PortfolioPage')
 
 #  Settings
 
