@@ -6,13 +6,8 @@ from lxml import etree
 from django.shortcuts import render
 from django.db import models
 from django.conf import settings
-from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
-from django.http import Http404
-from django.template.response import TemplateResponse
-from django.http import HttpResponse
 
 from wagtail.admin.edit_handlers import FieldPanel
-from wagtail.core.url_routing import RouteResult
 from wagtail.core import fields
 from wagtail.core.models import Page
 from wagtail.admin.edit_handlers import StreamFieldPanel
@@ -23,15 +18,16 @@ from wagtail.documents.blocks import DocumentChooserBlock
 
 from modelcluster.fields import ParentalKey
 from modelcluster.tags import ClusterTaggableManager
-from taggit.models import Tag, TaggedItemBase
+from taggit.models import TaggedItemBase
 
 from webspace.bakery.abstract import WagtailPageBakeryModel
 from webspace.cms import constants
 from webspace.cms.amp.mixins import AmpMixin
 from webspace.cms.forms.abstract import FormMixin
-from webspace.cms.amp.utils import amp_mode_active
 from webspace.loader import get_model, get_class
 
+from ._mixins import TagMixin
+
 GenericPage = get_model('cms', 'GenericPage')
 Person = get_model('cms', 'Person')
 
@@ -161,7 +157,7 @@ class ABlogPage(AmpMixin, FormMixin, WagtailPageBakeryModel, GenericPage):
         return context
 
 
-class ABlogIndexPage(AmpMixin, WagtailPageBakeryModel, GenericPage):
+class ABlogIndexPage(TagMixin, AmpMixin, WagtailPageBakeryModel, GenericPage):
     subpage_types = ['BlogPage']
     template = '%s/blog_index_page.html' % constants.PAGES_TEMPLATES_PATH
     bg_desktop = StreamField([
@@ -185,85 +181,3 @@ class ABlogIndexPage(AmpMixin, WagtailPageBakeryModel, GenericPage):
     class Meta:
         abstract = True
         app_label = 'cms'
-
-    def route(self, request, path_components):
-        if path_components:
-            if path_components[0] == 'tags':
-                tag_slug = path_components[1]
-                try:
-                    tag = Tag.objects.get(slug__iexact=tag_slug)
-                except Tag.DoesNotExist:
-                    raise Http404
-                if self.live:
-                    return RouteResult(self, kwargs={"tag": tag})
-                raise Http404
-            else:
-                path_components[0] = path_components[0]
-        return super(ABlogIndexPage, self).route(request, path_components)
-
-    @property
-    def blogs(self):
-        BlogPage = get_model('cms', 'BlogPage')
-        blogs = BlogPage.objects.live().descendant_of(self)
-        blogs = blogs.order_by('-date')
-        return blogs
-
-    def get_context(self, request, tag=None):
-        blogs = self.blogs
-        if tag:
-            blogs = blogs.filter(tags__slug=tag.slug)
-        page = request.GET.get('page')
-        paginator = Paginator(blogs,
-                              getattr(settings, 'WAGTAIL_BLOG_POSTS_PER_PAGE', 10))
-        try:
-            blogs = paginator.page(page)
-        except PageNotAnInteger:
-            blogs = paginator.page(1)
-        except EmptyPage:
-            blogs = paginator.page(paginator.num_pages)
-        context = super(ABlogIndexPage, self).get_context(request)
-        context['blogs'] = blogs
-
-        # FIXME start: tags must be have wagtail `Site`
-
-        tags_exist = Tag.objects.filter(cms_blogpagetag_items__isnull=False).distinct()
-        tags = []
-        for tag_item in tags_exist:
-            site = tag_item.cms_blogpagetag_items.first().content_object.get_site()
-            if site.id == request.site.id:
-                tags.append(tag_item)
-        context['tags'] = tags
-
-        # FIXME end
-
-        context['current_tag'] = tag
-        return context
-
-    def serve(self, request, *args, **kwargs):
-        if 'tag' not in kwargs:
-            return super(ABlogIndexPage, self).serve(request)
-
-        #  Serve tag pages
-        is_building = request.GET.get('build', False)
-        request.is_preview = getattr(request, 'is_preview', False)
-        if settings.DEBUG or request.is_preview or is_building:
-            self.active_language(request)
-            return TemplateResponse(
-                request,
-                self.get_template(request),
-                self.get_context(request, kwargs['tag'])
-            )
-        else:
-            site = self.get_site()
-            path_file = self.relative_url(site)
-            index = 'index.html' if request.user_agent.is_pc else 'index-mobile.html'
-            if amp_mode_active():
-                index = index.replace('.html', '-amp.html')
-                path_file = path_file.replace('/amp', '')
-            with open(settings.BUILD_DIR + '/' + site.hostname + '/' + path_file + 'tags/' + kwargs[
-                'tag'].slug + '/' + index, "rb") as fd:
-                compressed = fd.read()
-                response = HttpResponse(compressed)
-                response['Content-Encoding'] = 'gzip'
-                response['Content-Length'] = str(len(compressed))
-                return response
