@@ -75,7 +75,7 @@ def embed(url):
         ret = ret.replace('src=', 'class="lazy" data-src=')
         return ret
     except EmbedException:
-        return "<iframe class='lazy' data-src='%s'></iframe>" % url
+        return "<iframe title='embed' class='lazy' data-src='%s'></iframe>" % url
 
 
 @register.filter
