@@ -18,8 +18,6 @@ class MinifySchema(Node):
             return json.dumps(json.loads(ld))
         except Exception:
             logger.error(str(ld))
-            import pdb
-            pdb.set_trace()
             return ''
 
 
